@@ -1,4 +1,4 @@
 from .simple_losses import CrossEntropyLoss, MultiObjectiveLoss
 from .classificaion import DifferentiableArgmax, ParabolicPenaltyLoss, TailedCategoricalCrossentropyLoss
-from .probabilistic import HeteroscedasticityLoss
+from .probabilistic import HeteroscedasticityLoss, DistributionNLL
 from .soft_dtw import SoftDTW
\ No newline at end of file
